summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJeff Forcier <jeff@bitprophet.org>2017-08-21 15:58:17 -0700
committerJeff Forcier <jeff@bitprophet.org>2017-08-21 15:58:17 -0700
commitbcd613a765c22f3e92aa73e3a8a1adb0a0db34ab (patch)
tree75a25a16e44b1fb1be643fb10a9d04b833160bf5
parent681ff029b124faffdbb11ada646fab10aba83e55 (diff)
downloadparamiko-bcd613a765c22f3e92aa73e3a8a1adb0a0db34ab.tar.gz
Clarify docstring now that I understand better
-rw-r--r--paramiko/rsacert.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/paramiko/rsacert.py b/paramiko/rsacert.py
index eb64728a..28e21278 100644
--- a/paramiko/rsacert.py
+++ b/paramiko/rsacert.py
@@ -13,10 +13,10 @@ class RSACert(RSAKey):
"""
Certificate-bearing form of `.RSAKey`, compatible with OpenSSH 5.4+.
- Where `.RSAKey` requires only the private key material to operate,
- `RSACert` requires both the private key *and* a signed
- (public-key-wrapping) certificate file. For details on the format of
- certificate files, see the `official SSH certificate format specification
+ Where `.RSAKey` requires public or private key material to operate,
+ `RSACert` may take just certificate data, or certificate data plus
+ (private) key data. For details on the format of certificate files, see the
+ `official SSH certificate format specification
<http://cvsweb.openbsd.org/cgi-bin/cvsweb/src/usr.bin/ssh/PROTOCOL.certkeys?rev=HEAD>`_.
Certificate-based authentication can simplify authentication without
@@ -27,7 +27,8 @@ class RSACert(RSAKey):
.. note::
For all parameters besides those documented here, see `.RSAKey`; they
- are identical.
+ are identical. Thus, ``filename`` and ``file_obj`` (for example) are
+ for private key data and **not** certificate data.
:param str cert_filename:
Path to certificate file. Must be given if ``cert_file_obj`` is not